<?php

namespace EventPortal\Domain\Event\Form\Models;

use EventPortal\Domain\Event\Form\Enums\FormType;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Arr;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;
use Spatie\Enum\Laravel\HasEnums;

class Form extends Model implements AuditableInterface
{
    use HasEnums, Auditable;

    public const KEY = 'form';

    protected $enums = [
        'type' => FormType::class,
    ];

    protected $with = [
        'steps.sections.questions.options',
        'steps.sections.questions.validations',
    ];

    /** @var array<string> */
    protected $fillable = [
        'name',
        'type',
        'uuid',
        'event_id',
    ];

    public function event(): BelongsTo
    {
        return $this->belongsTo(Event::class);
    }

    public function steps(): HasMany
    {
        return $this->hasMany(FormStep::class);
    }

    public function scopeForEvent(Builder $query, Event $event): Builder
    {
        return $query->where('event_id', $event->id);
    }

    public function createOrUpdateStep(array $data): FormStep
    {
        return FormStep::updateOrCreate(
            ['id' => Arr::get($data, 'id')],
            Arr::add($data, 'form_id', $this->id)
        );
    }
}
