<?php

namespace EventPortal\Domain\Event\Form\Models;

use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Arr;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class FormStep extends Model implements AuditableInterface
{
    use Auditable, SoftDeletes;

    /** @var array<string> */
    protected $fillable = [
        'name',
        'order',
        'form_id',
        'uuid',
    ];

    public function form(): BelongsTo
    {
        return $this->belongsTo(Form::class);
    }

    public function sections(): HasMany
    {
        return $this->hasMany(FormStepSection::class);
    }

    public function createOrUpdateSection(array $data): FormStepSection
    {
        return FormStepSection::updateOrCreate(
            ['id' => Arr::get($data, 'id')],
            Arr::add($data, 'form_step_id', $this->id)
        );
    }
}
