<?php

namespace EventPortal\Domain\Event\Form\Models;

use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Arr;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class FormStepSection extends Model implements AuditableInterface
{
    use Auditable, SoftDeletes;

    /** @var array<string> */
    protected $fillable = [
        'name',
        'order',
        'form_step_id',
        'uuid',
    ];

    public function formStage(): BelongsTo
    {
        return $this->belongsTo(FormStep::class);
    }

    public function questions(): HasMany
    {
        return $this->hasMany(Question::class);
    }

    public function createOrUpdateQuestion(array $data): Question
    {
        return Question::updateOrCreate(
            ['id' => Arr::get($data, 'id')],
            Arr::add($data, 'form_step_section_id', $this->id)
        );
    }
}
