<?php

namespace EventPortal\Domain\Event\Form\Models;

use EventPortal\Domain\Event\Form\Enums\GdprType;
use EventPortal\Domain\Event\Form\Enums\QuestionType;
use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Arr;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;
use Spatie\Enum\Laravel\HasEnums;

class Question extends Model implements AuditableInterface
{
    use HasEnums, Auditable, SoftDeletes;

    protected $enums = [
        'type' => QuestionType::class,
        'gdpr_type' => GdprType::class,
    ];

    /** @var array<string> */
    protected $fillable = [
        'name',
        'type',
        'help_text',
        'help_position',
        'form_step_section_id',
        'gdpr_type',
        'order',
        'uuid',
    ];

    public function stage(): BelongsTo
    {
        return $this->belongsTo(FormStep::class);
    }

    public function options(): HasMany
    {
        return $this->hasMany(QuestionOption::class);
    }

    public function validations(): HasMany
    {
        return $this->hasMany(QuestionValidation::class);
    }

    public function createOrUpdateOption(array $data): QuestionOption
    {
        return QuestionOption::updateOrCreate(
            ['id' => Arr::get($data, 'id')],
            Arr::add($data, 'question_id', $this->id)
        );
    }

    public function createOrUpdateValidation(array $data): QuestionValidation
    {
        return QuestionValidation::updateOrCreate(
            ['id' => Arr::get($data, 'id')],
            Arr::add($data, 'question_id', $this->id)
        );
    }
}
