<?php

namespace EventPortal\Domain\Event\Form\Models;

use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class QuestionValidation extends Model implements AuditableInterface
{
    use Auditable;

    /** @var array<string> */
    protected $fillable = [
        'rule',
        'message',
        'question_id',
    ];

    public function question(): BelongsTo
    {
        return $this->belongsTo(Question::class);
    }

    public function scopeByQuestion(Builder $query, Question $question): Builder
    {
        return $query->where('question_id', '=', $question->id);
    }

    public function scopeIsRequired(Builder $query): Builder
    {
        return $query->where('rule', '=', 'required');
    }
}
