<?php

namespace EventPortal\Domain\Table;

use EventPortal\Domain\Component\Column\ActionColumn;
use EventPortal\Domain\Component\Column\Column;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;

class Columns
{
    /** @var \Illuminate\Support\Collection */
    private $columns;

    public function __construct(Collection $columns)
    {
        $this->columns = $columns;
    }

    public static function make(Collection $columns): self
    {
        return new static($columns);
    }

    public function getColumns(): Collection
    {
        return $this->columns;
    }

    public function forSelect(Model $model): array
    {
        return $this
            ->columns
            ->reject(function (Column $column) {
                return $column instanceof ActionColumn;
            })
            ->pluck('name')
            ->prepend($model->getQualifiedKeyName())
            ->toArray();
    }

    public function forSearch(): array
    {
        return $this
            ->columns
            ->reject(function (Column $column) {
                return $column->value !== null;
            })
            ->reject(function (Column $column) {
                return $column instanceof ActionColumn;
            })
            ->filter(function (Column $column) {
                return $column->isSearchable();
            })
            ->pluck('name')
            ->toArray();
    }
}
