<?php

namespace EventPortal\Http\Controllers\Admin\Event\Form;

use EventPortal\Domain\Event\Form\Actions\CreateForm;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Form\Requests\StoreFormRequest;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Render;
use EventPortal\Domain\Util\Sidebar\Facades\Sidebar;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Inertia\Inertia;
use Inertia\Response;

class FormController extends Controller
{
    public function index(Event $event): Response
    {
        $table = Table::make('form.index')
            ->context($event)
            ->query(Form::forEvent($event))
            ->request(request())
            ->get();

        $sidebar = Sidebar::make('event.show')
            ->user(auth()->user())
            ->model(request()->event)
            ->render();

        return Render::component('EventForm/Index')
            ->withTable($table)
            ->key('form.index')
            ->withSideBar($sidebar)
            ->get();
    }

    public function create(): Response
    {
        return Render::component('EventForm/Create')
            ->key('form.create')
            ->get();
    }

    public function edit(Event $event, Form $form): Response
    {
        return Inertia::render('EventForm/Edit', [
            'forms' => $form->toJson(),
            'event' => $event->id,
        ]);
    }

    public function store(
        StoreFormRequest $request,
        Event $event,
        CreateForm $createForm
    ): RedirectResponse {
        $createForm->execute($event, $request->all());

        return redirect()->route('admin.form.index', ['event' => $event]);
    }

    public function update(
        StoreFormRequest $request,
        Event $event,
        CreateForm $createForm
    ): void {
        $this->store($request, $event, $createForm);
    }
}
