<?php

namespace EventPortal\Tests\Unit\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Actions\CreateForm;
use EventPortal\Domain\Event\Form\Enums\FormType;
use EventPortal\Domain\Event\Form\Enums\GdprType;
use EventPortal\Domain\Event\Form\Enums\QuestionType;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class CreateFormTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_a_form(): void
    {
        $event = factory(Event::class)->create();

        (new CreateForm)->execute($event, $this->getFormData());

        $form = Form::first();
        $this->assertEquals('Test Form', $form->name);
        $step = $form->steps->first();
        $this->assertEquals('Test Stage', $step->name);
        $this->assertEquals('Test uuid', $step->uuid);
        $section = $step->sections->first();
        $this->assertEquals('Test Section', $section->name);
        $this->assertEquals('Test uuid', $section->uuid);
        $question = $section->questions->first();
        $this->assertEquals('Test Question', $question->name);
        $this->assertEquals('Test uuid', $question->uuid);
        $this->assertEquals('Test Help', $question->help_text);
        $this->assertEquals('after', $question->help_position);
        $option = $question->options->first();
        $this->assertEquals('Test Option', $option->name);
        $this->assertEquals('Test uuid', $option->uuid);
        $requiredValidation = $question->validations->first();
        $validation = $question->validations->last();
        $this->assertEquals('required', $requiredValidation->rule);
        $this->assertEquals('This field is required', $requiredValidation->message);
        $this->assertEquals('test rule', $validation->rule);
        $this->assertEquals('test message', $validation->message);
    }

    private function getFormData(): array
    {
        return [
            'name' => 'Test Form',
            'type' => FormType::Registration(),
            'steps' => [
                [
                    'name' => 'Test Stage',
                    'order' => 1,
                    'uuid' => 'Test uuid',
                    'sections' => [
                         [
                             'name' => 'Test Section',
                             'order' => 1,
                             'uuid' => 'Test uuid',
                             'questions' => [
                                 [
                                     'name' => 'Test Question',
                                     'type' => QuestionType::SingleLineTextBox(),
                                     'help_text' => 'Test Help',
                                     'help_position' => 'after',
                                     'gdpr_type' => GdprType::Private(),
                                     'order' => 1,
                                     'uuid' => 'Test uuid',
                                     'required' => true,
                                     'options' => [
                                         [
                                             'name' => 'Test Option',
                                             'order' => 1,
                                             'uuid' => 'Test uuid',
                                         ],
                                     ],
                                     'validations' => [
                                         [
                                             'rule' => 'test rule',
                                             'message' => 'test message',
                                         ],
                                     ],
                                 ],
                             ],
                         ],
                    ],
                ],
            ],
        ];
    }
}
